#include "dcdialog.ch"

#xtranslate NTrim(<n>)   =>  LTrim(Str(<n>))

#define CRLF  Chr(13)+Chr(10)

CLASS DD787 FROM CustomWebHandler

  EXPORTED:
    METHOD Rsvp

ENDCLASS

* ---------

METHOD DD787:rsvp

LOCAL cHtml, oForm, aVars, cAction, cErrorMessage, lSendForm, i, ;
      cValue, cReplace

::setErrorBlock()
BEGIN SEQUENCE

oForm := RSVPForm():new()
aVars := oForm:getAllVars(::httpRequest:form)

cAction := ::httpRequest:queryString

wtf cAction

cErrorMessage := ''
lSendForm := ValidateVars(aVars,@cErrorMessage)

IF lSendForm

  TEXT INTO cHtml
  <html>
  <head>
  <title>USS James E. Kyes Reunion RSVP</title>
  <link rel="stylesheet" type="text/css" href="donnay.css" />
  </head>
  <body bgcolor="#FFFFFF" background="./backgrounds/grey.jpg">
  ENDTEXT

  cHtml += MemoRead('rsvp787.htm')
  FOR i := 1 TO Len(aVars)
    cValue := aVars[i,2]
    cReplace := IIF(!Empty(cValue),'value="' + cValue+'"',"") + ' name="' + aVars[i,1] + '"'
    cHtml := Strtran( cHtml, '@' + aVars[i,1] + '@', cReplace )
    cHtml := Strtran( cHtml, '%' + aVars[i,1] + '%', aVars[i,3] )
  NEXT
  cHtml := Strtran( cHtml, '%errormessage%', cErrorMessage )
  cHtml += '</body></html>'

ELSEIF 'ConfirmRSVP' $ cAction

wtf 'confirm'

  cHtml := ConfirmRSVP(oForm)

ELSEIF 'PlaceRSVP' $ cAction

wtf 'place'

  cHtml := PlaceRSVP(oForm,aVars)
ENDIF

RECOVER USING cHtml
END SEQUENCE

RETURN  cHtml

* ---------

FUNCTION ValidateVars(aVars,cErrorMessage)

LOCAL i, cVarName, cValue, lError := .f., nQty := 0

FOR i := 1 TO Len(aVars)
  cVarName := aVars[i,1]
  cValue := Trim(aVars[i,2])
  IF cVarName $ {'name','street1','city','zip','email','phone','state'} .AND. Empty(cValue)
    aVars[i,3] := ' ***'
    lError := .t.
  ELSEIF cVarName = 'email' .AND. !('@'$cValue)
    aVars[i,3] := ' Invalid email address'
    lError := .t.
  ELSE
    aVars[i,3] := ''
  ENDIF
NEXT

IF lError
  cErrorMessage := 'Fields marked by *** are required'
ENDIF

RETURN lError

* ---------

FUNCTION PlaceRSVP( oForm, aVars )

LOCAL cError, cResponse := '', cText, i, cVarName, cValue

TEXT INTO cText
Please review your RSVP information below.  If everything is correct,
click on the CONFIRM button, otherwise click on the BACK button of your
Web browser and make the necessary changes.

<H4>NOTE: Your RSVP will not be processed until you click on <B>CONFIRM</B></H4>
ENDTEXT

cText := StrTran( cText, '<<NAME>>',oForm:name)
cText := StrTran( cText, '<<EMAIL>>',oForm:email)
cText += RSVPText( oForm, 1 )
cResponse += cText

cResponse += '<FORM ACTION="./RSVP?ConfirmRSVP" METHOD=GET>'
cResponse += '<INPUT TYPE=SUBMIT NAME="ConfirmRSVP" VALUE="Confirm!">'
cResponse += ReplicateVars( aVars, {'PlaceRSVP'} )
cResponse += '</FORM>'

RETURN cResponse

* ----------

FUNCTION ConfirmRSVP( oForm )

LOCAL cText, cHtml := '', cFileName

cText := MemoRead('rsvp787.txt')
cText := StrTran( cText, '<<NAME>>',oForm:name)
cText := StrTran( cText, '<<EMAIL>>',oForm:email)
cText += RSVPText( oForm, 2 )

cFileName := Dtos(Date())+ '_'+Time()+'_Email.txt'
cFileName := Strtran(cFileName,':','')

MemoWrit( cFileName,cText )
// EMAIL response to Client
SendMail( ,, Alltrim(oForm:email), 'USS James E. Kyes Reunion RSVP Confirmation',,, cText )

cText := MemoRead('rsvp787.txt')
cText := StrTran( cText, '<<NAME>>',oForm:name)
cText := StrTran( cText, '<<EMAIL>>',oForm:email)
cText += RSVPText( oForm, 1 ) // EMAIL response to Secretary

// EMAIL response to Secretary
SendMail( ,Alltrim(oForm:email), 'RogerDonnay@Donnay-Software.Com', ;
          'USS James E. Kyes Reunion RSVP Confirmation',,, cText )

cHtml += '<p>An email message has been sent to <b><em>' + Alltrim(oForm:email) + ;
         ' </em></b>with confirmation of your RSVP'

RETURN cHtml

* ----------

STATIC FUNCTION RSVPText( oForm, nMode )

LOCAL cText := ''

cText += CRLF
IF nMode = 1
  cText += '<pre>' + CRLF
ENDIF
cText += '            Name: ' + oForm:name       + CRLF
cText += '       Address 1: ' + oForm:street1    + CRLF
cText += '       Address 2: ' + oForm:street2    + CRLF
cText += '            City: ' + oForm:city       + CRLF
cText += '           State: ' + oForm:state      + CRLF
cText += '             Zip: ' + oForm:zip        + CRLF
cText += '           Phone: ' + oForm:phone      + CRLF
cText += '           Email: ' + oForm:email      + CRLF
cText += '  Years on Board: ' + oForm:years      + CRLF

cText += 'Remarks: ' + Strtran(oForm:remarks,CRLF+CRLF,CRLF)                           + CRLF

RETURN cText

* -----------

STATIC FUNCTION ReplicateVars( aVars, aExclude )

LOCAL i, cResponse := ''

DEFAULT aExclude := {}

FOR i := 1 TO Len(aVars)
  IF aVars[i,1] $ aExclude
    LOOP
  ENDIF
  cResponse += '<input type=hidden name="' + ;
               aVars[i,1] + '" value="' + ;
               aVars[i,2] + '">' + CRLF
NEXT

RETURN cResponse

* -----------

CLASS RSVPForm
EXPORTED:
VAR city
VAR email
VAR name
VAR phone
VAR remarks
VAR state
VAR street1
VAR street2
VAR zip
VAR years

INLINE METHOD init
LOCAL aVars, i
aVars := ::classdescribe()[3]
FOR i := 1 TO Len(aVars)
  ::&(aVars[i,1]) := ''
NEXT
RETURN self

* ---------

INLINE METHOD getAllVars(oForm)
LOCAL aVars, i, c
aVars := ::classdescribe()[3]
FOR i := 1 TO Len(aVars)
  aVars[i,1] := Lower(aVars[i,1])
  aVars[i,2] := oForm:&(aVars[i,1])
  ::&(aVars[i,1]) := aVars[i,2]
  aVars[i,3] := ''
NEXT
ASort(aVars,,,{|a,b|a[1]<b[1]})
RETURN aVars

ENDCLASS


